@@ -1,4 +1,4 @@
-centralityPlot <- function(..., labels, relative = TRUE, include)
+centralityPlot <- function(..., labels, standardized = TRUE, relative = FALSE, include, theme_bw = TRUE, print = TRUE)
 {
   # Some dummies to get rid of NOTES:
   measure <- NULL
@@ -6,7 +6,10 @@ centralityPlot <- function(..., labels, relative = TRUE, include)
   node <- NULL
   type <- NULL
   
-  Long <- centralityTable(..., labels=labels, relative=relative)
+  ## I realize I should have used a more appropriate programmatic way of doing this. My
+  ## programming is bad and I fo feel bad.
+  
+  Long <- centralityTable(..., standardized=standardized, labels=labels, relative=relative)
 
   # If not missing, include only include vars:
   if (!missing(include))
@@ -14,8 +17,12 @@ centralityPlot <- function(..., labels, relative = TRUE, include)
     Long <- subset(Long, measure %in% include)
   }
   
+
   # Ordereing by node name to make nice paths:
-  Long <- Long[order(Long$node),] 
+  Long <- Long[gtools::mixedorder(Long$node),] 
+  Long$node <- factor(as.character(Long$node), levels = unique(gtools::mixedsort(as.character(Long$node))))
+  
+  
   # PLOT:
   if (length(unique(Long$type)) > 1)
   {
@@ -33,8 +40,17 @@ centralityPlot <- function(..., labels, relative = TRUE, include)
   {
     g <- g + facet_grid( ~ measure, scales = "free") 
   }
+  
+  if (theme_bw){
+    g <- g + theme_bw()
+  }
 
-  return(g)  
+  if (print){
+    print(g)
+    invisible(g)
+  } else {
+    return(g)
+  }
 }
 
 
