@@ -360,7 +360,8 @@ if (length(alpha) > 4) stop("`alpha' can not have length > 4")
   } else labels <- qgraphObject$Arguments$labels
 
   if (is.expression(labels)) labels <- as.list(labels)
-
+  
+  if(is.null(qgraphObject$Arguments[['background']])) background <- NULL else background <- qgraphObject$Arguments[['background']]
   if(is.null(qgraphObject$Arguments[['label.prop']])) label.prop <- 0.9 else label.prop <- qgraphObject$Arguments[['label.prop']]
   if(is.null(qgraphObject$Arguments[['label.norm']])) label.norm <- "OOO" else label.norm <- qgraphObject$Arguments[['label.norm']]
   if(is.null(qgraphObject$Arguments[['label.cex']])) label.cex <- NULL else label.cex <- qgraphObject$Arguments[['label.cex']]
@@ -846,8 +847,10 @@ if(is.null(qgraphObject$Arguments[['noPar']])) noPar <- FALSE else noPar <- qgra
   #if (!filetype%in%c('pdf','png','jpg','jpeg','svg','R','eps','tiff')) warning(paste("File type",filetype,"is not supported")) 
   
   # Specify background:
-  background <- par("bg")
-  if (background == "transparent") background <- "white"
+  if (is.null(background)){
+    background <- par("bg")
+    if (background == "transparent") background <- "white"    
+  }
   if (isColor(bg)) background <- bg
   # Remove alpha:
   background <- col2rgb(background, alpha = TRUE)
